muse_ui
UI elements for Flutter
The current repository is created out of personal interest and my experience in front-end development, as a Flutter-based UI library project.
The goal of this project is to build a practical, convenient, and simple Flutter UI component library.
This aims to facilitate daily complex business development by focusing on business functionality and custom component development.
UI Widgets
Getting started
Install muse_ui
$ flutter pub add muse_ui
Import it
import 'package:muse_ui/button/muse_button.dart';
import 'package:muse_ui/button/types.dart';
License
MIT