MuseButton class

Inheritance

Constructors

MuseButton({Key? key, String? text, IconData? icon, ButtonType type = ButtonType.normal, ButtonSize size = ButtonSize.normal, ButtonNativeType nativeType = ButtonNativeType.normal, ButtonBorderType borderType = ButtonBorderType.normal, ButtonColors? colors, bool hairline = false, bool disabled = false, bool autofocus = false, MainAxisSet? axisSet, IconAlignment? iconPosition, EdgeInsetsGeometry? padding, Gradient? gradient, List<BoxShadow>? boxShadow, double? width, double? height, double? fontSize, double? iconSize, double? iconGap, VoidCallback? click, VoidCallback? longPress, Widget? slot})
const

Properties

autofocus bool
final
axisSet MainAxisSet?
final
borderType ButtonBorderType
final
boxShadow List<BoxShadow>?
final
click VoidCallback?
final
colors ButtonColors?
final
disabled bool
final
fontSize double?
final
gradient Gradient?
final
hairline bool
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
icon IconData?
final
iconGap double?
final
iconPosition IconAlignment?
final
iconSize double?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
longPress VoidCallback?
final
nativeType ButtonNativeType
final
padding EdgeInsetsGeometry?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size ButtonSize
final
slot Widget?
final
text String?
final
type ButtonType
final
width double?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited