MuseCell class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- MuseCell
Constructors
- MuseCell({Key? key, IconData? icon, double? iconSize, double? rightIconSize, Color? iconColor, Color? rightIconColor, CellSize size = CellSize.normal, String? title, String? value, String? label, Widget? slotIcon, Widget? slotRightIcon, Widget? slotTitle, Widget? slotValue, Widget? slotLabel, bool center = false, bool clickable = false, bool isLink = false, bool border = true, bool required = false, ArrowDirection arrowDirection = ArrowDirection.right, VoidCallback? click})
-
const
Properties
- arrowDirection → ArrowDirection
-
final
- border → bool
-
final
- center → bool
-
final
- click → VoidCallback?
-
final
- clickable → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData?
-
final
- iconColor → Color?
-
final
- iconSize → double?
-
final
- isLink → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
final
- required → bool
-
final
- rightIconColor → Color?
-
final
- rightIconSize → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → CellSize
-
final
- slotIcon → Widget?
-
final
- slotLabel → Widget?
-
final
- slotRightIcon → Widget?
-
final
- slotTitle → Widget?
-
final
- slotValue → Widget?
-
final
- title → String?
-
final
- value → String?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
getLabel(
) → Widget? -
getTitle(
) → Widget? -
getValue(
) → Widget? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited