Default class
Constructors
- Default()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- alphaDisable → const int
- alphaEnable → const int
- alphaPressed → const int
- colorBorder → const Color
- colorDanger → const Color
- colorFont → const Color
- colorFontGray → const Color
- colorInfo → const Color
- colorPrimary → const Color
- colorWarning → const Color
- fontSize → const double
- fontSizeLarge → const double
- fontSizeMini → const double
- fontSizeSmall → const double
- gap → const double
- radius → const double
- radiusRound → const double
- radiusSquare → const double
- textAlign → const TextAlign