Utils class
Constructors
- Utils()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getColorPressed(
Color color) → WidgetStateProperty< Color?> -
getLRList(
Widget left, double gap, Widget right) → List< Widget> -
horizontalRow(
Widget? w1, Widget? w2, {MainAxisAlignment axisAlignment = MainAxisAlignment.start}) → Widget? -
renderText(
Widget? slotWidget, String? text, AlignmentGeometry alignment, TextStyle? textStyle) → Widget?